@@ -3,7 +3,6 @@
 var inspect = require("util").inspect;
 var sinon = require("sinon");
 var referee = require("@sinonjs/referee");
-var formatio = require("@sinonjs/formatio");
 
 var assert = referee.assert;
 var refute = referee.refute;
@@ -11,12 +10,6 @@ var expect = referee.expect;
 
 referee = require("./referee-sinon");
 
-var formatter = formatio.configure({ quoteStrings: false });
-
-referee.format = function () {
-  return formatter.ascii.apply(formatter, arguments);
-};
-
 function requiresSpy(assertion) {
   // eslint-disable-next-line no-empty-function
   var args = [function () {}, "dummy argument"].concat(
@@ -58,6 +51,7 @@ describe("referee-sinon", function () {
 
   describe("mapping", function () {
     var DISALLOWED_METHODS = [
+      "createAssertObject",
       "expose",
       "fail",
       // this can be achieved with refute.calledWith
@@ -68,28 +62,30 @@ describe("referee-sinon", function () {
       "notCalled",
       "pass",
     ];
+    // eslint-disable-next-line mocha/no-setup-in-describe
     var sinonMethods = Object.keys(sinon.assert).filter(function (key) {
+      // eslint-disable-next-line mocha/no-setup-in-describe
       var isDisallowed = DISALLOWED_METHODS.indexOf(key) !== -1;
+      // eslint-disable-next-line mocha/no-setup-in-describe
       var isFunction = typeof sinon.assert[key] === "function";
 
       return !isDisallowed && isFunction;
     });
 
+    // eslint-disable-next-line mocha/no-setup-in-describe
     sinonMethods.forEach(function (methodName) {
-      it("should map '" + methodName + "' from sinon.assert", function () {
+      it(`should map '${methodName}' from sinon.assert`, function () {
         assert.isFunction(referee.assert[methodName]);
         assert.isFunction(referee.refute[methodName]);
       });
     });
 
+    // eslint-disable-next-line mocha/no-setup-in-describe
     DISALLOWED_METHODS.forEach(function (methodName) {
-      it(
-        "must not map disallowed '" + methodName + "' from sinon.assert",
-        function () {
-          assert.isUndefined(referee.assert[methodName]);
-          assert.isUndefined(referee.refute[methodName]);
-        }
-      );
+      it(`must not map disallowed '${methodName}' from sinon.assert`, function () {
+        assert.isUndefined(referee.assert[methodName]);
+        assert.isUndefined(referee.refute[methodName]);
+      });
     });
   });
 
@@ -113,10 +109,10 @@ describe("referee-sinon", function () {
           throw new Error("Exception expected");
         } catch (e) {
           var message =
-            "[assert.calledWith] Expected " +
-            inspect(spy) +
-            " to be called with arguments null, 2, 2" +
-            "\n    spy(null, 1, 2)";
+            `[assert.calledWith] Expected ${inspect(
+              spy
+            )} to be called with arguments null, 2, 2` +
+            `\n    spy(null, 1, 2)`;
           assert.match(e.message, message);
         }
       });
@@ -137,10 +133,10 @@ describe("referee-sinon", function () {
           throw new Error("Exception expected");
         } catch (e) {
           var message =
-            "[assert.calledWith] Expected " +
-            inspect(fake) +
-            " to be called with arguments null, 2, 2" +
-            "\n    fake(null, 1, 2)";
+            `[assert.calledWith] Expected ${inspect(
+              fake
+            )} to be called with arguments null, 2, 2` +
+            `\n    fake(null, 1, 2)`;
           assert.match(e.message, message);
         }
       });
@@ -153,11 +149,9 @@ describe("referee-sinon", function () {
           assert.calledWith(fake, null);
           throw new Error("Exception expected");
         } catch (e) {
-          var message =
-            "[assert.calledWith] Expected " +
-            inspect(fake) +
-            " to be called with arguments null" +
-            "\n    fake(Error)";
+          var message = `[assert.calledWith] Expected ${inspect(
+            fake
+          )} to be called with arguments null\n    fake(Error)`;
           assert.match(e.message, message);
         }
       });
@@ -182,10 +176,10 @@ describe("referee-sinon", function () {
           throw new Error("Exception expected");
         } catch (e) {
           var message =
-            "[assert.calledWithExactly] Expected " +
-            inspect(spy) +
-            " to be called with exact " +
-            "arguments null, 2, 2\n    spy(null, 1, 2)";
+            `[assert.calledWithExactly] Expected ${inspect(
+              spy
+            )} to be called with exact ` +
+            `arguments null, 2, 2\n    spy(null, 1, 2)`;
           assert.match(e.message, message);
         }
       });
@@ -220,10 +214,10 @@ describe("referee-sinon", function () {
           throw new Error("Exception expected");
         } catch (e) {
           var message =
-            "[assert.calledWithMatch] Expected " +
-            inspect(spy) +
-            " to be called with matching " +
-            "arguments { check: 321 }\n    spy({ check: 123 })";
+            `[assert.calledWithMatch] Expected ${inspect(
+              spy
+            )} to be called with matching ` +
+            `arguments { check: 321 }\n    spy({ check: 123 })`;
           assert.match(e.message, message);
         }
       });
@@ -294,12 +288,21 @@ describe("referee-sinon", function () {
           assert.calledOnceWithMatch(spy, null, 2, 2);
           throw new Error("Exception expected");
         } catch (e) {
-          var message =
-            "[assert.calledOnceWithMatch] Expected " +
-            inspect(spy) +
-            " to be called once with matching arguments " +
-            "null, 2, 2\n    spy(null, 1, 2)";
-          assert.match(e.message, message);
+          var message1 = `[assert.calledOnceWithMatch] Expected ${inspect(
+            spy
+          )} to be called once with matching arguments null, 2, 2, but was called with null, 1, 2`;
+          assert.match(e.message, message1);
+        }
+
+        spy(null, 1, 2);
+        try {
+          assert.calledOnceWithMatch(spy, null, 2, 2);
+          throw new Error("Exception expected");
+        } catch (e) {
+          var message2 = `Expected ${inspect(
+            spy
+          )} to be called once, but was called 2 times`;
+          assert.match(e.message, message2);
         }
       });
     });
@@ -333,11 +336,9 @@ describe("referee-sinon", function () {
           assert.alwaysCalledWithMatch(spy, { check: 321 });
           throw new Error("Exception expected");
         } catch (e) {
-          var message =
-            "[assert.alwaysCalledWithMatch] Expected " +
-            inspect(spy) +
-            " to always be called with " +
-            "matching arguments { check: 321 }";
+          var message = `[assert.alwaysCalledWithMatch] Expected ${inspect(
+            spy
+          )} to always be called with matching arguments { check: 321 }`;
           var lines = e.message.split("\n");
           assert.equals(lines.length, 3);
           assert.equals(lines[0], message);
@@ -364,10 +365,9 @@ describe("referee-sinon", function () {
           assert.calledOnce(spy);
           throw new Error("Exception expected");
         } catch (e) {
-          var message =
-            "[assert.calledOnce] Expected " +
-            inspect(spy) +
-            " to be called once but was called 0 times";
+          var message = `[assert.calledOnce] Expected ${inspect(
+            spy
+          )} to be called once but was called 0 times`;
           assert.equals(e.message, message);
         }
       });
@@ -392,10 +392,9 @@ describe("referee-sinon", function () {
           assert.calledTwice(spy);
           throw new Error("Exception expected");
         } catch (e) {
-          var message =
-            "[assert.calledTwice] Expected " +
-            inspect(spy) +
-            " to be called twice but was called once";
+          var message = `[assert.calledTwice] Expected ${inspect(
+            spy
+          )} to be called twice but was called once`;
           assert.match(e.message, message);
           assert.match(e.message, "spy(null, 'Hey')");
         }
@@ -423,10 +422,9 @@ describe("referee-sinon", function () {
           assert.calledThrice(spy);
           throw new Error("Exception expected");
         } catch (e) {
-          var message =
-            "[assert.calledThrice] Expected " +
-            inspect(spy) +
-            " to be called thrice but was called twice";
+          var message = `[assert.calledThrice] Expected ${inspect(
+            spy
+          )} to be called thrice but was called twice`;
           assert.match(e.message, message);
           assert.match(e.message, "spy(null, 'Hey')");
           assert.match(e.message, "spy(null, 'Ho')");
@@ -453,10 +451,9 @@ describe("referee-sinon", function () {
           assert.callCount(spy, 1);
           throw new Error("Exception expected");
         } catch (e) {
-          var message =
-            "[assert.callCount] Expected " +
-            inspect(spy) +
-            " to be called exactly 1 times, but was called 0 times";
+          var message = `[assert.callCount] Expected ${inspect(
+            spy
+          )} to be called exactly 1 times, but was called 0 times`;
           assert.match(e.message, message);
         }
       });
@@ -479,11 +476,9 @@ describe("referee-sinon", function () {
           assert.called(spy);
           throw new Error("Exception expected");
         } catch (e) {
-          var message =
-            "[assert.called] Expected " +
-            inspect(spy) +
-            " to be called at least once but was never " +
-            "called";
+          var message = `[assert.called] Expected ${inspect(
+            spy
+          )} to be called at least once but was never called`;
           assert.equals(e.message, message);
         }
       });
@@ -509,10 +504,9 @@ describe("referee-sinon", function () {
           assert.calledWithNew(spy);
           throw new Error("Exception expected");
         } catch (e) {
-          var message =
-            "[assert.calledWithNew] Expected " +
-            inspect(spy) +
-            " to be called with 'new' at least once but was never called with 'new'";
+          var message = `[assert.calledWithNew] Expected ${inspect(
+            spy
+          )} to be called with 'new' at least once but was never called with 'new'`;
           assert.equals(e.message, message);
         }
       });
@@ -552,10 +546,9 @@ describe("referee-sinon", function () {
           assert.alwaysCalledWithNew(spy);
           throw new Error("Exception expected");
         } catch (e) {
-          var message =
-            "[assert.alwaysCalledWithNew] Expected " +
-            inspect(spy) +
-            " to always be called with 'new'";
+          var message = `[assert.alwaysCalledWithNew] Expected ${inspect(
+            spy
+          )} to always be called with 'new'`;
           assert.equals(e.message, message);
         }
       });
@@ -618,10 +611,10 @@ describe("referee-sinon", function () {
           throw new Error("Exception expected");
         } catch (e) {
           var message =
-            "[assert.calledOn] Expected " +
-            inspect(spy) +
-            " to be called with { id: 12 } as this but was " +
-            "called on { id: 42 }";
+            `[assert.calledOn] Expected ${inspect(
+              spy
+            )} to be called with { id: 12 } as this but was ` +
+            `called on { id: 42 }`;
           assert.equals(e.message, message);
         }
       });
@@ -656,10 +649,10 @@ describe("referee-sinon", function () {
           throw new Error("Exception expected");
         } catch (e) {
           var message =
-            "[assert.alwaysCalledOn] Expected " +
-            inspect(spy) +
-            " to always be called with { id: 12 } as " +
-            "this but was called on { id: 42 }";
+            `[assert.alwaysCalledOn] Expected ${inspect(
+              spy
+            )} to always be called with { id: 12 } as ` +
+            `this but was called on { id: 42 }`;
           assert.equals(e.message, message);
         }
       });
@@ -684,11 +677,9 @@ describe("referee-sinon", function () {
           assert.alwaysCalledWith(spy, 12);
           throw new Error("Exception expected");
         } catch (e) {
-          var message =
-            "[assert.alwaysCalledWith] Expected " +
-            inspect(spy) +
-            " to always be called with " +
-            "arguments 12\n    spy(42)";
+          var message = `[assert.alwaysCalledWith] Expected ${inspect(
+            spy
+          )} to always be called with arguments 12\n    spy(42)`;
           assert.match(e.message, message);
         }
       });
@@ -716,16 +707,23 @@ describe("referee-sinon", function () {
           throw new Error("Exception expected");
         } catch (e) {
           var message =
-            "[assert.alwaysCalledWithExactly] Expected " +
-            inspect(spy) +
-            " to always be called with " +
-            "exact arguments null, 2, 2\n    spy(null, 1, 2)";
+            `[assert.alwaysCalledWithExactly] Expected ${inspect(
+              spy
+            )} to always be called with ` +
+            `exact arguments null, 2, 2\n    spy(null, 1, 2)`;
           assert.match(e.message, message);
         }
       });
     });
 
     describe("calledOnceWithExactly", function () {
+      it("passes when called once with expected arguments", function () {
+        var spy = sinon.spy();
+        spy(42);
+
+        assert.calledOnceWithExactly(spy, 42);
+      });
+
       it(
         "fails when not called with spy",
         requiresSpy("calledOnceWithExactly")
@@ -756,13 +754,23 @@ describe("referee-sinon", function () {
           assert.calledOnceWithExactly(spy, null, 2, 2);
           throw new Error("Exception expected");
         } catch (e) {
-          var message =
-            "[assert.calledOnceWithExactly] Expected " +
-            inspect(spy) +
-            " to be called once with exact arguments " +
-            "null, 2, 2\n    spy(null, 1, 2)";
+          var message = `[assert.calledOnceWithExactly] Expected ${inspect(
+            spy
+          )} to be called once with exact arguments null, 2, 2, but was called with null, 1, 2`;
           assert.match(e.message, message);
         }
+
+        spy(null, 1, 2);
+
+        try {
+          assert.calledOnceWithExactly(spy, null, 2, 2);
+          throw new Error("Exception expected");
+        } catch (e) {
+          var message2 = `[assert.calledOnceWithExactly] Expected ${inspect(
+            spy
+          )} to be called once, but was called 2 times`;
+          assert.match(e.message, message2);
+        }
       });
     });
 
@@ -785,10 +793,9 @@ describe("referee-sinon", function () {
           assert.threw(spy);
           throw new Error("Exception expected");
         } catch (e) {
-          var message =
-            "[assert.threw] Expected " +
-            inspect(spy) +
-            " to throw an exception";
+          var message = `[assert.threw] Expected ${inspect(
+            spy
+          )} to throw an exception`;
           assert.equals(e.message, message);
         }
       });
@@ -822,10 +829,9 @@ describe("referee-sinon", function () {
           assert.alwaysThrew(spy);
           throw new Error("Exception expected");
         } catch (e) {
-          var message =
-            "[assert.alwaysThrew] Expected " +
-            inspect(spy) +
-            " to always throw an exception";
+          var message = `[assert.alwaysThrew] Expected ${inspect(
+            spy
+          )} to always throw an exception`;
           assert.equals(e.message, message);
         }
       });
@@ -867,12 +873,21 @@ describe("referee-sinon", function () {
           assert.calledOnceWith(spy, 12);
           throw new Error("Exception expected");
         } catch (e) {
-          var message =
-            "[assert.calledOnceWith] Expected " +
-            inspect(spy) +
-            " to be called once with arguments 12\n" +
-            "    spy(42)";
-          assert.match(e.message, message);
+          var message1 = `[assert.calledOnceWith] Expected ${inspect(
+            spy
+          )} to be called with arguments 12, but was called with 42`;
+          assert.match(e.message, message1);
+        }
+
+        spy(42);
+        try {
+          assert.calledOnceWith(spy, 42);
+          throw new Error("Exception expected");
+        } catch (e) {
+          var message2 = `[assert.calledOnceWith] Expected ${inspect(
+            spy
+          )} to be called once, but was called 2 times`;
+          assert.match(e.message, message2);
         }
       });
     });
